.minisite-dropdown-menu-container {
    width: 80%;
    margin: 0 auto;
    background: #e9e9e9;
}

.minisite-dropdown-menu-mobile {
    display: none;
    padding: 20px 20px 20px 14px;
}
.minisite-dropdown-menu-mobile:before{
    content: "\f008";
    font-family: "fontello";
    margin-right: 0.5em;
}
.minisite-dropdown-menu > ul.navTreeLevel0 {
    margin: 0 auto;
    width: 100%;
    list-style: none;
    padding: 0;
    position: relative;
    /* IF .minisite-dropdown-menuposition=relative -> ul = container width, ELSE ul = 100% width */
    box-sizing: border-box;
    background: transparent;
}

.minisite-dropdown-menu > ul:before,
.minisite-dropdown-menu > ul:after {
    content: "";
    display: table;
}

.minisite-dropdown-menu > ul:after {
    clear: both;
}

.minisite-dropdown-menu> ul.navTreeLevel0 > li {
    float: left;
    background: transparent;
    padding: 0;
    margin: 0;
}

.minisite-dropdown-menu > ul > li a {
    text-decoration: none;
    padding: 1.5em 3em;
    display: block;
}
.minisite-dropdown-menu > ul > li.menu-dropdown-icon > a::after {
    content: "\e844";
    font-family: fontello;
    margin-left: 0.25em;
}
.minisite-dropdown-menu .navTreeLevel0 > li:hover,
.minisite-dropdown-menu .navTreeLevel0 > .activated{
    background: #f0f0f0;
}

.minisite-dropdown-menu > ul > li > ul {
    display: none;
    width: 100%;
    background: #f0f0f0;
    padding: 20px;
    position: absolute;
    z-index: 99;
    left: 0;
    margin: 0;
    list-style: none;
    box-sizing: border-box;
}

.minisite-dropdown-menu > ul > li > ul:before,
.minisite-dropdown-menu > ul > li > ul:after {
    content: "";
    display: table;
}

.minisite-dropdown-menu > ul > li > ul:after {
    clear: both;
}
.navTree.navTreeLevel1.mega-sub {
    column-count: 3;
}
.minisite-dropdown-menu .navTreeLevel1.mega-sub > li {
    break-inside: avoid;
    display: inline-block;
    width:100%;
}
.minisite-dropdown-menu .navTreeLevel1 > li {
    margin: 0;
    padding-bottom: 0;
    padding-right: 1.5em;
    box-sizing: border-box;
    list-style: none;
    background: none;
}

.minisite-dropdown-menu ul.navTreeLevel1 > li > a {
    color: #333;
    display: block;
    box-sizing: border-box;
    position: relative;
    width:100%;
}
.minisite-dropdown-menu .navTreeLevel1 li a:hover {
    background: #fff;
}
.minisite-dropdown-menu ul.navTreeLevel1 > li > a:hover::before{
    border-bottom-color: #c9c9c9;
    left: 0;
}
.minisite-dropdown-menu ul.navTreeLevel1.mega-sub > li > a::before{
    content: "";
    position: absolute;
    height: 1px;
    border-bottom: 1px solid #333;
    bottom: 0;
    left: 0.5em;
    right: 0;
    transition: left 0.25s ease-in-out;
}
.minisite-dropdown-menu ul.navTreeLevel1.mega-sub > li > a:hover::before{
    left:0;
}
/*.minisite-dropdown-menu ul.navTreeLevel1.normal-sub > li > a::before{
    display: none;
}*/
.minisite-dropdown-menu ul.navTreeLevel2 {
    display: block;
    padding: 0;
    margin: 10px 0 0 0;
    list-style: none;
    box-sizing: border-box;
    background: transparent;
}
.minisite-dropdown-menu > ul > li > ul > li > ul:before,
.minisite-dropdown-menu > ul > li > ul > li > ul:after {
    content: "";
    display: table;
}

.minisite-dropdown-menu > ul > li > ul > li > ul:after {
    clear: both;
}

.minisite-dropdown-menu .navTreeLevel2 > li {
    float: left;
    width: 100%;
    padding: 0;
    margin: 0;
    font-size: 1em;
}

.minisite-dropdown-menu .navTreeLevel2 > li a {
    border: 0;
    margin:0;
    padding:0.5em 0.75em !important;
    text-transform: none !important;
    display: inline-block;
    width: 100%;
    box-sizing: border-box;
}
.minisite-dropdown-menu .navTreeLevel1 > li a {
    margin:0;
    padding: 0.6em !important;
}
.minisite-dropdown-menu > ul > li > ul.normal-sub {
    width: 300px;
    left: auto;
    padding: 10px 20px;
}

.minisite-dropdown-menu > ul > li > ul.normal-sub > li {
    width: 100%;
}

.minisite-dropdown-menu > ul > li > ul.normal-sub > li a {
    border: 0;
    padding: 1em 0;
}


@media only screen and (max-width: 768px) {
    .minisite-dropdown-menu .navTree.navTreeLevel1.mega-sub {
    column-count: 1;
    }
    .minisite-dropdown-menu-container {
        width: 100%;
    }
    .minisite-dropdown-menu-mobile {
        display: block;
    }
    .menu-dropdown-icon:before {
        display: block;
    }
    .minisite-dropdown-menu > ul {
        display: none;
    }
    .minisite-dropdown-menu > ul > li {
        width: 100%;
        float: none;
        display: block;
    }
    .minisite-dropdown-menu > ul.navTreeLevel0 > li a {
        padding: 1.5em;
        width: 100%;
        display: inline-block;
    }
    .minisite-dropdown-menu > ul > li.menu-dropdown-icon > a::after{
        float: left;
        margin-right: 0.5em;
    }
    .minisite-dropdown-menu > ul > li > ul {
        position: relative;
    }
    .minisite-dropdown-menu > ul > li > ul.normal-sub {
        width: 100%;
    }
    .minisite-dropdown-menu .navTreeLevel1 > li {
        float: none;
        width: 100%;
        margin-top: 20px;
    }
    .minisite-dropdown-menu > ul > li > ul > li:first-child {
        margin: 0;
    }
    .minisite-dropdown-menu > ul > li > ul > li > ul {
        position: relative;
    }
    .minisite-dropdown-menu > ul > li > ul > li > ul > li {
        float: none;
    }
    .minisite-dropdown-menu .show-on-mobile {
        display: block;
    }
}
