#bloc-actu {
    float: left;
    width: 50%;
}

#bloc-actu-title {
    float: left;
}

#bloc-actu-rss {
    float: right;
}

#bloc-event {
    float: left;
    width: 50%;
}

#bloc-event-title {
    float: left;
}

#bloc-event-rss {
    float: right;
}

#footer-sitemap div.footer-sitemap-item {
    float: left;
}

#footer-sitemap div.footer-static {
    float: left;
}

#content div.newsImageContainer {
    display: none;
}

#content div.leadImage {
    display: none;
}

div#formfield-form-widgets-IDublinCore-subjects  {
    display: none;
}

div.table-responsive {
    overflow-y: initial;
}

.hidden-right-panel {
	display: none;
}

.shown-right-panel {
	display: block;
}

#portal-footer-wrapper.row {
    clear: both;
}

.dynamic-hover {
	background-position: center !important;
}

.contact-entry-photos {
	padding-left: 0px !important;
	padding-right: 0px !important;
	padding-top: 0px !important;
}

.organization-photos {
	height: 70%;
}

.organization-informations {
	margin: 1em;
}

#content-views dl.actionMenu.activated dd {
    background-color: #75ad0a;
    color: White;
    z-index: 5;
    border-bottom: 0.5em solid #75ad0a;
    right: -3px;
    z-index: 1008;
}

#content-views dl.actionMenu {
    display: inline-block;
    float: none;
}

#content-views dl.actionMenu.activated dd a:hover,
#content-views dl.actionMenu.activated dd .actionMenuSelected {
    background-color: White !important;
    color: #666;
}

#content-views dl.actionMenu.activated dd a {
    border-top-right-radius: 0em;
    border-top-left-radius: 0em;
    -webkit-border-top-right-radius: 0em;
    -webkit-border-top-left-radius: 0em;
    -moz-border-radius-topleft: 0em;
    -moz-border-radius-topright: 0em;
}
a:focus, input:focus {
	outline-color: rgba(51, 51, 51, 0.555)!important;
	outline: thin solid;
	outline: 5px auto -webkit-focus-ring-color;
    outline-offset: -2px;
}

.template-newsitem_view #content-core a:link,
.template-event_booking #content-core .text a:link,
.template-document_view #content-core a:link,
.template-event_view #content-core a:link,
.portaltype-organization a:link,
.portaltype-procedure a:link,
.template-medialink_oembed_view a:link{
    text-decoration: underline;
}
